@@ -23,14 +23,17 @@
  * IN THE SOFTWARE.
  */
 
-#include <gio/gio.h>
+#include <stddef.h>  // for size_t
 
+#include <glib.h>
+
+#include "gjs/jsapi-wrapper.h"
+
+#include "gjs/atoms.h"
 #include "gjs/context-private.h"
 #include "gjs/engine.h"
-#include "global.h"
-#include "importer.h"
-#include "jsapi-util.h"
-#include "jsapi-wrapper.h"
+#include "gjs/global.h"
+#include "gjs/jsapi-util.h"
 
 GJS_JSAPI_RETURN_CONVENTION
 static bool
@@ -207,18 +210,20 @@ gjs_printerr(JSContext *context,
 }
 
 class GjsGlobal {
+    // clang-format off
     static constexpr JSClassOps class_ops = {
         nullptr,  // addProperty
         nullptr,  // deleteProperty
         nullptr,  // enumerate
-        nullptr,  // newEnumerate
-        nullptr,  // resolve
-        nullptr,  // mayResolve
+        JS_NewEnumerateStandardClasses,
+        JS_ResolveStandardClass,
+        JS_MayResolveStandardClass,
         nullptr,  // finalize
         nullptr,  // call
         nullptr,  // hasInstance
         nullptr,  // construct
         JS_GlobalObjectTraceHook};
+    // clang-format on
 
     static constexpr JSClass klass = {
         "GjsGlobal",
@@ -247,8 +252,7 @@ class GjsGlobal {
 
         JSAutoCompartment ac(cx, global);
 
-        if (!JS_InitStandardClasses(cx, global) ||
-            !JS_InitReflectParse(cx, global) ||
+        if (!JS_InitReflectParse(cx, global) ||
             !JS_DefineDebuggerObject(cx, global))
             return nullptr;
 
